@@ -91,6 +91,21 @@ set_date (TrackerSparqlCursor *cursor,
   }
 }
 
+static void
+set_favourite (TrackerSparqlCursor *cursor,
+               gint                 column,
+               GrlMedia            *media,
+               GrlKeyID             key)
+{
+  const gchar *str = tracker_sparql_cursor_get_string (cursor, column, NULL);
+  gboolean is_favourite = FALSE;
+
+  if (str != NULL && g_str_has_suffix (str, "predefined-tag-favorite"))
+    is_favourite = TRUE;
+
+  grl_data_set_boolean (GRL_DATA (media), key, is_favourite);
+}
+
 static void
 set_title_from_filename (TrackerSparqlCursor *cursor,
                          gint                 column,
@@ -360,10 +375,11 @@ grl_tracker_setup_key_mappings (void)
                       "nie:usageCounter(?urn)",
                       "media");
 
-  insert_key_mapping (GRL_METADATA_KEY_LAST_PLAYED,
-                      "nie:contentAccessed",
-                      "nie:contentAccessed(?urn)",
-                      "media");
+  insert_key_mapping_with_setter (GRL_METADATA_KEY_LAST_PLAYED,
+                                  "nie:contentAccessed",
+                                  "nie:contentAccessed(?urn)",
+                                  "media",
+                                  set_date);
 
   insert_key_mapping (GRL_METADATA_KEY_LAST_POSITION,
                       "nfo:lastPlayedPosition",
@@ -386,6 +402,12 @@ grl_tracker_setup_key_mappings (void)
                       "nmm:trackNumber",
                       "nmm:trackNumber(?urn)",
                       "audio");
+
+  insert_key_mapping_with_setter (GRL_METADATA_KEY_FAVOURITE,
+                                  "nao:hasTag",
+                                  "nao:hasTag(?urn)",
+                                  "audio",
+                                  set_favourite);
 }
 
 tracker_grl_sparql_t *
@@ -432,7 +454,7 @@ grl_tracker_source_get_select_string (const GList *keys)
 
   assoc_list = get_mapping_from_grl (grl_metadata_key_tracker_urn);
   assoc = (tracker_grl_sparql_t *) assoc_list->data;
-  g_string_append_printf (gstr, "%s AS %s ",
+  g_string_append_printf (gstr, "%s AS ?%s ",
                           assoc->sparql_key_attr_call,
                           assoc->sparql_key_name);
 
@@ -441,7 +463,7 @@ grl_tracker_source_get_select_string (const GList *keys)
     while (assoc_list != NULL) {
       assoc = (tracker_grl_sparql_t *) assoc_list->data;
       if (assoc != NULL) {
-        g_string_append_printf (gstr, "%s AS %s ",
+        g_string_append_printf (gstr, "%s AS ?%s ",
                                 assoc->sparql_key_attr_call,
                                 assoc->sparql_key_name);
       }
@@ -459,8 +481,9 @@ gen_prop_insert_string (GString *gstr,
                         GrlData *data)
 {
   gchar *tmp;
+  GType type = GRL_METADATA_KEY_GET_TYPE (assoc->grl_key);
 
-  switch (GRL_METADATA_KEY_GET_TYPE (assoc->grl_key)) {
+  switch (type) {
   case G_TYPE_STRING:
     tmp = g_strescape (grl_data_get_string (data, assoc->grl_key), NULL);
     g_string_append_printf (gstr, "%s \"%s\"",
@@ -480,7 +503,26 @@ gen_prop_insert_string (GString *gstr,
                             grl_data_get_float (data, assoc->grl_key));
     break;
 
+  case G_TYPE_BOOLEAN:
+    /* Special case for favourite tag, see comment in
+     * grl_tracker_tracker_get_insert_string for more details.
+     */
+    if (assoc->grl_key == GRL_METADATA_KEY_FAVOURITE) {
+      g_string_append_printf (gstr, "%s nao:predefined-tag-favorite",
+                              assoc->sparql_key_attr);
+    }
+    break;
+
   default:
+    if (type == G_TYPE_DATE_TIME) {
+      tmp = g_date_time_format (grl_data_get_boxed (data, assoc->grl_key),
+                                "%FT%T%:z");
+      g_string_append_printf (gstr, "%s '%s'",
+                              assoc->sparql_key_attr,
+                              tmp);
+
+      g_free (tmp);
+    }
     break;
   }
 }
@@ -489,36 +531,41 @@ gchar *
 grl_tracker_tracker_get_insert_string (GrlMedia *media, const GList *keys)
 {
   gboolean first = TRUE;
-  const GList *key = keys, *assoc_list;
-  tracker_grl_sparql_t *assoc;
+  const GList *key;
   GString *gstr = g_string_new ("");
-  gchar *ret;
 
-  while (key != NULL) {
-    assoc_list = get_mapping_from_grl (GRLPOINTER_TO_KEYID (key->data));
-    while (assoc_list != NULL) {
-      assoc = (tracker_grl_sparql_t *) assoc_list->data;
-      if (assoc != NULL) {
-        if (grl_data_has_key (GRL_DATA (media),
-                              GRLPOINTER_TO_KEYID (key->data))) {
-          if (first) {
-            gen_prop_insert_string (gstr, assoc, GRL_DATA (media));
-            first = FALSE;
-          } else {
-            g_string_append (gstr, " ; ");
-            gen_prop_insert_string (gstr, assoc, GRL_DATA (media));
-          }
-        }
-      }
-      assoc_list = assoc_list->next;
+  for (key = keys; key != NULL; key = key->next) {
+    const GList *assoc_list;
+    GrlKeyID key_id = GRLPOINTER_TO_KEYID (key->data);
+
+    for (assoc_list = get_mapping_from_grl (key_id);
+         assoc_list != NULL;
+         assoc_list = assoc_list->next) {
+      tracker_grl_sparql_t *assoc = assoc_list->data;
+
+      if (assoc == NULL)
+        continue;
+
+      /* The favourite key is really setting or deleting a tag
+       * in tracker, so in the case of setting it to false skip
+       * the insert string creation step for this key completely.
+       */
+      if (assoc->grl_key == GRL_METADATA_KEY_FAVOURITE &&
+          !grl_media_get_favourite (media))
+        continue;
+
+      if (!grl_data_has_key (GRL_DATA (media), key_id))
+        continue;
+
+      if (!first)
+        g_string_append (gstr, " ; ");
+
+      gen_prop_insert_string (gstr, assoc, GRL_DATA (media));
+      first = FALSE;
     }
-    key = key->next;
   }
 
-  ret = gstr->str;
-  g_string_free (gstr, FALSE);
-
-  return ret;
+  return g_string_free (gstr, FALSE);
 }
 
 gchar *
@@ -688,7 +735,7 @@ get_tracker_volume_name (const gchar *uri,
       if (g_file_equal (m_file, file)) {
         gchar *m_name = g_mount_get_name (G_MOUNT (mount->data));
         g_object_unref (G_OBJECT (m_file));
-        source_name = g_strdup_printf (_("Removable - %s"), m_name);
+        source_name = g_strdup_printf (_("Removable — %s"), m_name);
         g_free (m_name);
         break;
       }
@@ -709,7 +756,7 @@ get_tracker_volume_name (const gchar *uri,
 static gchar *
 get_tracker_upnp_name (const gchar *datasource_name)
 {
-  return g_strdup_printf ("UPnP - %s", datasource_name);
+  return g_strdup_printf ("UPnP — %s", datasource_name);
 }
 
 gchar *
